==> bootstrap-show-notification-1.0.2.tgz: package/README.md <==
# bootstrap-show-notification

A jQuery plugin wrapper around Bootstrap 4 Alerts, to create fixed Alerts (also called Notifications) dynamically in JavaScript.

![bootstrap-show-notification Example](https://shaack.com/projekte/assets/img/bootstrap-show-notification-lg.png)

## Try it

[Demo Page](https://shaack.com/projekte/bootstrap-show-notification/)

## Usage

```html
<script src="./src/bootstrap-show-notification.js"></script>
<script>
    $("#button-show-simple").click(function () {
        $.showNotification({body: "Hello Notification!"})
    })
    $("#button-show-info").click(function () {
        $.showNotification({
            body: "<h3>For your Info</h3>This notification has a title and a body and more text than the previous one.", type: "info"
        })
    })
    $("#button-show-danger").click(function () {
        $.showNotification({
            body: "Danger!", type: "danger"
        })
    })
</script>
```

## Props (defaults)

```js
props = {
    body: "",
    type: "primary",
    shadow: "0 2px 6px rgba(0,0,0,0.2)",
    zIndex: 100,
    margin: "1rem",
    dismissible: true,
    delay: 5000,
    containerId: "bootstrap-show-notification-container",
    breakpoint: "500px",
    width: "420px"
}
```

# More Bootstrap extensions from shaack.com

You may want to check out our other Bootstrap and HTML extensions

- [bootstrap-input-spinner](https://shaack.com/en/open-source-components) – Input numbers
- [bootstrap-show-modal](https://shaack.com/en/open-source-components) – Show dialogs, dynamically
- [bootstrap-show-notification](https://shaack.com/en/open-source-components) – Show notifications, dynamically
- [bootstrap-detect-breakpoint](https://shaack.com/en/open-source-components) – Read the curr. BS BP from JS
- [auto-resize-textarea](https://shaack.com/en/open-source-components) – Auto resize textareas by its content
- [external-links-blank](https://shaack.com/en/open-source-components) – Open external links auto `_blank`

==> bootstrap-show-notification-1.0.3.tgz: package/README.md <==
# bootstrap-show-notification

A jQuery plugin wrapper around Bootstrap 4 Alerts, to create fixed Alerts (also called Notifications) dynamically in JavaScript.

![bootstrap-show-notification Example](https://shaack.com/projekte/assets/img/bootstrap-show-notification-lg.png)

## Try it

[Demo Page](https://shaack.com/projekte/bootstrap-show-notification/)

## Usage

```html
<script src="./src/bootstrap-show-notification.js"></script>
<script>
    $("#button-show-simple").click(function () {
        $.showNotification({body: "Hello Notification!"})
    })
    $("#button-show-info").click(function () {
        $.showNotification({
            body: "<h3>For your Info</h3>This notification has a title and a body and more text than the previous one.", type: "info"
        })
    })
    $("#button-show-danger").click(function () {
        $.showNotification({
            body: "Danger!", type: "danger"
        })
    })
</script>
```

## Props (defaults)

```js
this.props = {
    body: "", // put here the text, shown
    type: "primary", // the appearance
    shadow: "0 2px 6px rgba(0,0,0,0.2)", // the box-shadow
    zIndex: 100,
    margin: "1rem", // the margin (only above "breakpoint")
    duration: 5000, // duration till auto-hide
    smallMode: "500px", // will be shown in smallMode, below this
    width: "420px", // the notification width (above small-mode)
    direction: "prepend" // or "append", the stack direction
}
```

# More Bootstrap extensions from shaack.com

You may want to check out our other Bootstrap and HTML extensions

- [bootstrap-input-spinner](https://shaack.com/en/open-source-components) – Input numbers
- [bootstrap-show-modal](https://shaack.com/en/open-source-components) – Show dialogs, dynamically
- [bootstrap-show-notification](https://shaack.com/en/open-source-components) – Show notifications, dynamically
- [bootstrap-detect-breakpoint](https://shaack.com/en/open-source-components) – Read the curr. BS BP from JS
- [auto-resize-textarea](https://shaack.com/en/open-source-components) – Auto resize textareas by its content
- [external-links-blank](https://shaack.com/en/open-source-components) – Open external links auto `_blank`
